Method: Inflections#acronym

Defined in:
lib/build/ExtendedString.rb

#acronym(word) ⇒ Object

Specifies a new acronym. An acronym must be specified as it will appear in a camelized string. An underscore string that contains the acronym will retain the acronym when passed to camelize, humanize, or titleize. A camelized string that contains the acronym will maintain the acronym when titleized or humanized, and will convert the acronym into a non-delimited single lowercase word when passed to underscore.



104
105
106
107
# File 'lib/build/ExtendedString.rb', line 104

def acronym(word)
  @acronyms[word.downcase] = word
  @acronym_regex = /#{@acronyms.values.join("|")}/
end